
/** @file spi.c
 * @brief SPI-Library template.
 * @author Clemens Helfmeier
 * @date 25.06.06
 *
 * The SPI-library is fully architecture and device specific, and thus
 * this generic library only does nothing than echo every byte.
 * Compile and link the spi_${ARCH}.c instead.
 */

#include "spi.h"

/* this file contains an empty spi body.
 */
#warning "USING EMPTY SPI-LIBRARY. Compile spi_${Controller}.c instead!"


/** @brief Initialize the SPI hardware.
 *
 * This function is called once upon system startup. It should put all SPI devices
 * to "not selected".
 */
void spi_init( void ) {
}

/** @brief Start a SPI transfer.
 * @param dev	Device to start the transfer with.
 * 
 * The transfer is started by simply pulling the CS-line of the specified device
 * down. No data is sent and no data recieved yet.
 */
void spi_start( void* dev ) {
}

/** @brief End a SPI transfer
 *
 * Ending of a transfer is done by deselecting the previously selected chip.
 */
void spi_end( void ) {
}

/** @brief Send and recieve a datum.
 * @param send The datum to be send.
 * @return Returns the value read on the MISO line
 * 
 * Sending and recieving at the same time is supported by this function.
 * The length depends on the device's settings, max 16 bits, MSB first is sent.
 */
unsigned short spi_xmit( unsigned short send ) {
	 return send;
}

/** @brief Send a datum.
 * @param send	The datum to be send.
 * 
 * This function sends out one datum. The transfer can still be in progress even
 * if the function already returned. The return value is not examined and will
 * stay in the recieve buffer until spi_rmit is called. Usually, the recieve
 * buffer can contain exactly one datum.
 */
void spi_tmit( unsigned short send ) {
}

/** @brief Read the next value from the recieve buffer. If no value available wait
 * until the running transfer finishes.
 * @return The value read from the recieve buffer.
 *
 * This function will return the next value in the order of reception. If no datum
 * is available, the function will wait until one is available. There will never
 * be a transfer started with this function! If the recieve buffer is empty and
 * not transfer is running, the function will never return.
 */
unsigned short spi_rmit( void ) {
}

/** @brief Transmit a block of data and recieve into the same buffer.
 * @param data	Pointer to the data to be transmitted.
 * @param len	The number of datums to be send and recieved.
 *
 * If the device uses 9 or more	 bits per datum, the pointer points to an array of
 * 16 bit values, each containing the data to be send in their lower 9 bits. The
 * buffer will be overwritten by the recieved data. The function returns as soon
 * as possible. The transfer could last longer than the function call. The user must
 * take care of the buffer not to be freed until the transfer is finished.
 * @see spi_wait
 */
void spi_bxmit( void *data, unsigned short len ) {
}

/** @brief Transmit a block of data.
 * @param data	Pointer to the data to be transmitted.
 * @param len	The number of datums to be send and recieved.
 *
 * If the device uses 9 or more	 bits per datum, the pointer points to an array of
 * 16 bit values, each containing the data to be send in their lower 9 bits. This
 * function doesn't recieve the data returned by the slave device. They are discarded.
 * The function returns as soon as possible. The transfer could last longer than
 * the function call. The user must take care of the buffer not to be freed until
 * the transfer is finished.
 * @see spi_wait
 */
void spi_btmit( void *data, unsigned short len ) {
}

/** @brief Wait until the last transfer is finished.
 *
 * This function waits until the SPI transfers are all finished.
 */
void spi_wait( void ) {
}


